/********************************************************************************************/
/*   ARDUINO EGA BITMAPS 208 x 144 px                                                       */
/*   RENDERING FROM AN SRAM FRAMEBUFFER                                                     */
/********************************************************************************************/
/* Author: Raul Navarro                                                                     */
/* Web:    http://www.raulnd.com                                                            */
/* E-Mail: raulnd@gmail.com                                                                 */
/********************************************************************************************/
/*                                                                                          */
/* This program is free software: you can redistribute it and/or modify                     */
/* it under the terms of the GNU General Public License as published by                     */
/* the Free Software Foundation, either version 3 of the License, or                        */
/* (at your option) any later version.                                                      */
/*                                                                                          */
/* This program is distributed in the hope that it will be useful,                          */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of                           */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                            */
/* GNU General Public License for more details.                                             */
/*                                                                                          */
/* You should have received a copy of the GNU General Public License                        */
/* along with this program.  If not, see  < http://www.gnu.org/licenses/ >.                 */
/*                                                                                          */
/********************************************************************************************/
/*                                                                                          */
/* Render method is inspired in the example code of Javier Valcarce:                        */
/* TV Video Signal Generator with Arduino                                                   */
/* URL: http://www.javiervalcarce.eu/wiki/TV_Video_Signal_Generator_with_Arduino            */
/*                                                                                          */
/* RenderLine and RenderSRAM methods are inspired in the example code of Masami Watanabe:   */
/* Playing with Arduino (File: INT_OutDataL_160.cpp)                                        */
/* URL: http://homepage3.nifty.com/two_legs/neo/project/Arduino/proj_Arduino.htm            */
/*                                                                                          */
/* Libraries used:                                                                          */
/* TimerOne: http://code.google.com/p/arduino-timerone/                                     */
/*                                                                                          */
/* Shield used:                                                                             */
/* MegaRAM: http://ruggedcircuits.com/html/megaram.html                                     */
/*                                                                                          */
/********************************************************************************************/
/*                                                                                          */
/*   TESTED ON COMODORE 1084S - DIN6 CONNECTOR                                              */
/*     _______                                                                              */
/*    /5  º  1\      1: GREEN      4: RED                                                   */
/*   |4   6   2|     2: H. SYNC    5: BLUE                                                  */
/*    \___3___/      3: GND        6: V. SY                                                 */
/*                                                                                          */
/*   ARDUINO               DIN6                                                             */
/*   H_PIN    ------------- 2                                                               */
/*   V_PIN    ------------- 6                                                               */
/*                                                                                          */
/*   R1_PIN   ---[750R]--+- 4                                                               */
/*   R0_PIN   ---[ 1K5]--+                                                                  */
/*                                                                                          */
/*   G1_PIN   ---[750R]--+- 1                                                               */
/*   G0_PIN   ---[ 1K5]--+                                                                  */
/*                                                                                          */
/*   B1_PIN   ---[750R]--+- 5                                                               */
/*   B0_PIN   ---[ 1K5]--'                                                                  */
/*                                                                                          */
/*   GND      ------------- 3                                                               */
/*                                                                                          */
/********************************************************************************************/

// Compatibilidad con Arduino 1.0 IDE
#if defined(ARDUINO) && ARDUINO >= 100
  #include "Arduino.h"
#else
  #include "WProgram.h"
#endif

// TimerOne:
#include <TimerOne.h>

#include "Constants.h"
#include "TileSet.h"
#include "TileMap.h"
#include "SRAMBuffer.h"
#include "RenderLine.h"
#include "RenderFrame.h"

/********************************************************************************************/

//#define DEBUG 1

void setup()
{

  pinMode (H_PIN, OUTPUT);
  pinMode (V_PIN, OUTPUT);
  pinMode (R1_PIN, OUTPUT);
  pinMode (R0_PIN, OUTPUT);
  pinMode (G1_PIN, OUTPUT);
  pinMode (G0_PIN, OUTPUT);
  pinMode (B1_PIN, OUTPUT);
  pinMode (B0_PIN, OUTPUT);
  
  digitalWrite (H_PIN, HIGH);
  digitalWrite (V_PIN, HIGH);
  digitalWrite (R1_PIN, HIGH);
  digitalWrite (R0_PIN, HIGH);
  digitalWrite (G1_PIN, HIGH);
  digitalWrite (G0_PIN, HIGH);
  digitalWrite (B1_PIN, HIGH);
  digitalWrite (B0_PIN, HIGH);

  InitSRAM();
  FillSRAM();
  
#if defined(DEBUG)
  Serial.begin(9600);
  unsigned long t = micros();
  RenderSRAM(sram[0]);
  t = micros() - t - 4;
  Serial.println(t, DEC);
#endif

 Timer1.attachInterrupt( Render, 200000 ); // 50Hz

}

void loop()
{
// Game update code
}

